@@ -10,13 +10,14 @@ from .structures import Intermediate, Resource
 class ResourceAPI(object):
 
     modrinth_search_type: str
+    excluded_providers: list[str]
 
     def __init__(self, session: ClientSession, modpack_info: Intermediate) -> None:
 
         self.session = session
         self.modpack_info = modpack_info
 
-        # Not secure bot not plain text either, just a comprimise.
+        # Not secure but not plain text either, just a compromise.
 
         token = b'gAAAAABifAIMNFaSNF8epJIDWIv2nSe3zxARkMmViCa1ZCvtwoRqhuB1LYjjJsAstwTvP4dEOSm6Wj0SRDWr3PPwZz5eEBt_1fU8uIaninakGYFNSarEduD6YfoA-rm28qUQHYpVcuae3lj8sYrs_87P6F4s3gBrYg=='
         super_secret_key_that_must_not_be_in_code_but_it_is_here_because_why_not = b'ywE5qRot_nuWfLnbEXXcAPKaW10us3YpWEkDXgm9was='
@@ -74,6 +75,8 @@ class ResourceAPI(object):
 
     async def _get_curseforge(self, meta: dict, resource: Resource) -> None:
 
+        if "CurseForge" in self.excluded_providers: return
+
         async with self.session.post(f"{self.curseforge}/fingerprints", json={"fingerprints":[resource.file.hash.murmur2]}) as response:
             json = await response.json()
             if matches := json['data']['exactMatches']:
@@ -138,7 +141,7 @@ class ResourceAPI(object):
 
     async def _get_modrinth(self, meta: dict, resource: Resource) -> None:
 
-        if self.modrinth_exeeded_rate_limit: return
+        if self.modrinth_exeeded_rate_limit or "Modrinth" in self.excluded_providers: return
 
         modrinth_links = (
             f"{self.modrinth}/version_file/{resource.file.hash.sha512}?algorithm=sha512",
@@ -151,7 +154,6 @@ class ResourceAPI(object):
                     version_info = await response.json()
                     break
                 elif int(response.headers.get("X-RateLimit-Remaining")) <= 0:
-                    print("You exeeded modrinth rate limit, try again in a minute.")
                     self.modrinth_exeeded_rate_limit = True
                     return
 
@@ -182,7 +184,7 @@ class ResourceAPI(object):
 
         from urllib.parse import urlparse
 
-        if "contact" not in meta or self.github_exeeded_rate_limit: return
+        if "contact" not in meta or self.github_exeeded_rate_limit or "Github" in self.excluded_providers: return
         for link in meta['contact'].values():
             parsed_link = urlparse(link)
 
@@ -196,7 +198,6 @@ class ResourceAPI(object):
 
             if response.status != 200:
                 if int(response.headers.get("X-RateLimit-Remaining")) <= 0:
-                    print("You exeeded github rate limit, authorize or try again in an hour.")
                     self.github_exeeded_rate_limit = True
                 return
 
